@@ -281,9 +281,15 @@ class SpotifyOAuth(SpotifyAuthBase):
         self.requests_timeout = requests_timeout
         self.show_dialog = show_dialog
 
-    def get_cached_token(self):
-        """ Gets a cached auth token
-        """
+    def get_cached_token(self, storage_type='file'):
+        """ Gets a cached auth token"""
+        if storage_type == 'file':
+            return self._get_cached_file_token()
+        elif storage_type == 'db':
+            return self._get_cached_db_token()
+
+    def _get_cached_file_token(self):
+        """ Gets a cached auth token from file"""
         token_info = None
 
         if not self.cache_path and self.username:
@@ -315,6 +321,10 @@ class SpotifyOAuth(SpotifyAuthBase):
                 pass
         return token_info
 
+    def _get_cached_db_token(self):
+        """ Gets a cached auth token from database"""
+        pass
+
     def _save_token_info(self, token_info):
         if self.cache_path:
             try:
