@@ -2,23 +2,17 @@
 
 """ Shows a user's playlists (need to be authenticated via oauth) """
 
-__all__ = ["CLIENT_CREDS_ENV_VARS", "prompt_for_user_token"]
+__all__ = ["prompt_for_user_token"]
 
 import logging
 import os
 import warnings
 
-import spotipy
+from .exceptions import SpotifyException
+from .oauth2 import SpotifyOAuth
 
 LOGGER = logging.getLogger(__name__)
 
-CLIENT_CREDS_ENV_VARS = {
-    "client_id": "SPOTIPY_CLIENT_ID",
-    "client_secret": "SPOTIPY_CLIENT_SECRET",
-    "client_username": "SPOTIPY_CLIENT_USERNAME",
-    "redirect_uri": "SPOTIPY_REDIRECT_URI",
-}
-
 
 def prompt_for_user_token(
     username,
@@ -77,11 +71,11 @@ def prompt_for_user_token(
                     https://developer.spotify.com/my-applications
             """
             )
-            raise spotipy.SpotifyException(550, -1, "no credentials set")
+            raise SpotifyException(550, -1, "no credentials set")
 
         cache_path = cache_path or ".cache-" + username
 
-    sp_oauth = oauth_manager or spotipy.SpotifyOAuth(
+    sp_oauth = oauth_manager or SpotifyOAuth(
         client_id,
         client_secret,
         redirect_uri,
@@ -107,14 +101,3 @@ def prompt_for_user_token(
         return token
     else:
         return None
-
-
-def get_host_port(netloc):
-    if ":" in netloc:
-        host, port = netloc.split(":", 1)
-        port = int(port)
-    else:
-        host = netloc
-        port = None
-
-    return host, port
